# wenbot
Simple bot wrapper of selenium basic functions

Sample code:
```
TODO
```

# optional proxy support
Requires browsermob-proxy binary, see https://github.com/lightbody/browsermob-proxy/releases.
Requires java to run browsermob-proxy binary.
Default browsermob-proxy binary path is set in `wenbot.browsermob_proxy_bin`.
Requires pypi package *browsermobproxy*, install `pip install browsermobproxy`.

Sample code:
```
TODO
```

